/****************************************************************************
** Meta object code from reading C++ file 'qgtk3dialoghelpers.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/QGnomePlatform/src/qgtk3dialoghelpers.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qgtk3dialoghelpers.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_QGtk3ColorDialogHelper_t {
    QByteArrayData data[3];
    char stringdata0[35];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QGtk3ColorDialogHelper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QGtk3ColorDialogHelper_t qt_meta_stringdata_QGtk3ColorDialogHelper = {
    {
QT_MOC_LITERAL(0, 0, 22), // "QGtk3ColorDialogHelper"
QT_MOC_LITERAL(1, 23, 10), // "onAccepted"
QT_MOC_LITERAL(2, 34, 0) // ""

    },
    "QGtk3ColorDialogHelper\0onAccepted\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QGtk3ColorDialogHelper[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void QGtk3ColorDialogHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QGtk3ColorDialogHelper *_t = static_cast<QGtk3ColorDialogHelper *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onAccepted(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject QGtk3ColorDialogHelper::staticMetaObject = {
    { &QPlatformColorDialogHelper::staticMetaObject, qt_meta_stringdata_QGtk3ColorDialogHelper.data,
      qt_meta_data_QGtk3ColorDialogHelper,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *QGtk3ColorDialogHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QGtk3ColorDialogHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_QGtk3ColorDialogHelper.stringdata0))
        return static_cast<void*>(const_cast< QGtk3ColorDialogHelper*>(this));
    return QPlatformColorDialogHelper::qt_metacast(_clname);
}

int QGtk3ColorDialogHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPlatformColorDialogHelper::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_QGtk3FileDialogHelper_t {
    QByteArrayData data[3];
    char stringdata0[34];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QGtk3FileDialogHelper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QGtk3FileDialogHelper_t qt_meta_stringdata_QGtk3FileDialogHelper = {
    {
QT_MOC_LITERAL(0, 0, 21), // "QGtk3FileDialogHelper"
QT_MOC_LITERAL(1, 22, 10), // "onAccepted"
QT_MOC_LITERAL(2, 33, 0) // ""

    },
    "QGtk3FileDialogHelper\0onAccepted\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QGtk3FileDialogHelper[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void QGtk3FileDialogHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QGtk3FileDialogHelper *_t = static_cast<QGtk3FileDialogHelper *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onAccepted(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject QGtk3FileDialogHelper::staticMetaObject = {
    { &QPlatformFileDialogHelper::staticMetaObject, qt_meta_stringdata_QGtk3FileDialogHelper.data,
      qt_meta_data_QGtk3FileDialogHelper,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *QGtk3FileDialogHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QGtk3FileDialogHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_QGtk3FileDialogHelper.stringdata0))
        return static_cast<void*>(const_cast< QGtk3FileDialogHelper*>(this));
    return QPlatformFileDialogHelper::qt_metacast(_clname);
}

int QGtk3FileDialogHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPlatformFileDialogHelper::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_QGtk3FontDialogHelper_t {
    QByteArrayData data[3];
    char stringdata0[34];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QGtk3FontDialogHelper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QGtk3FontDialogHelper_t qt_meta_stringdata_QGtk3FontDialogHelper = {
    {
QT_MOC_LITERAL(0, 0, 21), // "QGtk3FontDialogHelper"
QT_MOC_LITERAL(1, 22, 10), // "onAccepted"
QT_MOC_LITERAL(2, 33, 0) // ""

    },
    "QGtk3FontDialogHelper\0onAccepted\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QGtk3FontDialogHelper[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void QGtk3FontDialogHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QGtk3FontDialogHelper *_t = static_cast<QGtk3FontDialogHelper *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onAccepted(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject QGtk3FontDialogHelper::staticMetaObject = {
    { &QPlatformFontDialogHelper::staticMetaObject, qt_meta_stringdata_QGtk3FontDialogHelper.data,
      qt_meta_data_QGtk3FontDialogHelper,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *QGtk3FontDialogHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QGtk3FontDialogHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_QGtk3FontDialogHelper.stringdata0))
        return static_cast<void*>(const_cast< QGtk3FontDialogHelper*>(this));
    return QPlatformFontDialogHelper::qt_metacast(_clname);
}

int QGtk3FontDialogHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPlatformFontDialogHelper::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
